==> KGRUBEditor-0.8.1-src.tar.bz2: kgrubeditor-0.8.1/src/map.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Konstantinos Smanis                             *
 *   kon.smanis@gmail.com                                                  *
 *                                                                         *
 *   This file is part of KGRUBEditor.                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor                                       *
 *   Boston, MA  02111-1307, USA.                                          *
 ***************************************************************************/

#ifndef MAP_H
#define MAP_H

//KDE
#include <kassistantdialog.h>

//Ui
#include "ui_map_assistant_intro.h"
#include "ui_map_assistant_step1.h"
#include "ui_map_assistant_step2.h"
#include "ui_map_assistant_summary.h"

//KGRUBEditor
#include "core/datatypes.h"

/**
 * @short Map Assistant.
 *
 * Creates / edits GRUB maps step-to-step.
 */
class MapAssistant : public KAssistantDialog
{
Q_OBJECT
public:
	/**
	* Sets up the GUI and shows the password.
	*
	* @param map The GRUB Map to create/edit.
	* @param parent QWidget parent. Self explanatory.
	*/
	MapAssistant( GRUB::ComplexCommand::Map *map, QWidget *parent = 0 );
	/**
	* Desctructor.
	*/
	~MapAssistant();
private:
	/**
	* Connects all signals to their slots.
	*/
	void setupConnections();
private:
	/**
	* Checks if a device already exists in the combo box of devices.
	* Makes sure that no duplicates are entered in this comboBox.
	*
	* @param device The device to check.
	*
	* @return whether the device already exists in the combobox or not.
	*/
	bool alreadyExists( const QString &device );
private slots:
	/**
	* Before accessing the last page, it collects all data
	* that where entered by the user and creates a summary.
	*/
	void nextClicked();
	/**
	* If the Finish button is pressed, finalises all changes
	* done to the map.
	*/
	void finishClicked();
private:
	Ui::map_assistant_intro ui_intro;
	Ui::map_assistant_step1 ui_step1;
	Ui::map_assistant_step2 ui_step2;
	Ui::map_assistant_summary ui_summary;

	KPageWidgetItem *summaryPage;

	GRUB::ComplexCommand::Map *m_map;
};

#endif

==> KGRUBEditor-0.8.5b-src.tar.bz2: kgrubeditor-0.8.5b/src/map.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Konstantinos Smanis                             *
 *   kon.smanis@gmail.com                                                  *
 *                                                                         *
 *   This file is part of KGRUBEditor.                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor                                       *
 *   Boston, MA 02110-1301, USA.                                          *
 ***************************************************************************/

#ifndef MAP_EDITOR_H
#define MAP_EDITOR_H

//KDE
#include <kdialog.h>

//Ui
#include "ui_mapeditor.h"

//KGRUBEditor
#include "core/datatypes.h"

/**
 * @short Map Editor.
 *
 * Creates / edits GRUB maps.
 */
class MapEditor : public KDialog, private Ui::MapEditor
{
Q_OBJECT
public:
	/**
	* Sets up the GUI and shows the map.
	*
	* @param map The GRUB Map to create/edit.
	* @param parent QWidget parent. Self explanatory.
	*/
	MapEditor( GRUB::ComplexCommand::Map *map, QWidget *parent = 0 );
	/**
	* Desctructor.
	*/
	~MapEditor();
private:
	/**
	* Connects all signals to their slots.
	*/
	void setupConnections();
private slots:
	/**
	* Checks whether both maps are empty.
	* If not, the user is allowed to procede.
	*/
	void checkMaps();
	/**
	* Triggered when OK is clicked in order to save all
	* changes done to the original map.
	*/
	void okClicked();
private:
	GRUB::ComplexCommand::Map *m_map;
};

#endif
